@@ -29,7 +29,7 @@ namespace Glom
 {
 
 FileChooser_Export::FileChooser_Export()
-: Gtk::FileChooserDialog(_("Export To File."), Gtk::FILE_CHOOSER_ACTION_SAVE),
+: Gtk::FileChooserDialog(_("Export to File"), Gtk::FILE_CHOOSER_ACTION_SAVE),
   m_extra_widget(false, Utils::DEFAULT_SPACING_SMALL),
 #ifndef GLOM_ENABLE_CLIENT_ONLY
   m_button_format(_("Define Data _Format"), true /* use mnenomic */),
@@ -37,8 +37,10 @@ FileChooser_Export::FileChooser_Export()
 #endif //GLOM_ENABLE_CLIENT_ONLY
   m_document(0)
 {
+  set_icon_name("glom");
+
   add_button(Gtk::Stock::CANCEL, Gtk::RESPONSE_CANCEL);
-  add_button(_("Export"), Gtk::RESPONSE_OK);
+  add_button(_("_Export"), Gtk::RESPONSE_OK);
 
   m_extra_widget.pack_start(m_button_format, Gtk::PACK_SHRINK);
 
@@ -53,24 +55,13 @@ FileChooser_Export::FileChooser_Export()
 
 #ifndef GLOM_ENABLE_CLIENT_ONLY
   //TODO: Use a generic layout dialog?
-#ifdef GLIBMM_EXCEPTIONS_ENABLED  
-  Glib::RefPtr<Gtk::Builder> refXml = Gtk::Builder::create_from_file(Utils::get_glade_file_path("glom_developer.glade"), "window_data_layout_export");
-#else
-  std::auto_ptr<Glib::Error> error;  
-  Glib::RefPtr<Gtk::Builder> refXml = Gtk::Builder::create_from_file(Utils::get_glade_file_path("glom_developer.glade"), "window_data_layout_export", error);
-#endif
-
-  if(refXml)
-  {
-    Dialog_Layout_Export* dialog = 0;
-    refXml->get_widget_derived("window_data_layout_export", dialog);
-    if(dialog)
-    {
-      m_pDialogLayout = dialog;
-      //add_view(m_pDialogLayout); //Give it access to the document.
-      m_pDialogLayout->signal_hide().connect( sigc::mem_fun(*this, &FileChooser_Export::on_dialog_layout_hide) );
-    }
-  }
+  Dialog_Layout_Export* dialog = 0;
+  Utils::get_glade_widget_derived_with_warning(dialog);
+  
+  m_pDialogLayout = dialog;
+  m_pDialogLayout->set_icon_name("glom");
+  //add_view(m_pDialogLayout); //Give it access to the document.
+  m_pDialogLayout->signal_hide().connect( sigc::mem_fun(*this, &FileChooser_Export::on_dialog_layout_hide) );
 #endif //GLOM_ENABLE_CLIENT_ONLY
 }
 
