@@ -29,6 +29,7 @@
 #include <glibmm/i18n.h>
 
 #include <libglom/gst-package.h>
+#include <sstream> //For stringstream
 
 #ifdef G_OS_WIN32
 # include <windows.h>
@@ -73,39 +74,39 @@ namespace ConnectionPoolBackends
 // incompatibly: http://www.postgresql.org/about/press/features84#security
  
 #define DEFAULT_CONFIG_PG_HBA_LOCAL_8p3 \
-"# TYPE  DATABASE    USER        CIDR-ADDRESS          METHOD\n\
-\n\
-# local is for Unix domain socket connections only\n\
-# trust allows connection from the current PC without a password:\n\
-local   all         all                               trust\n\
-local   all         all                               ident sameuser\n\
-local   all         all                               md5\n\
-\n\
-# TCP connections from the same computer, with a password:\n\
-host    all         all         127.0.0.1    255.255.255.255    md5\n\
-# IPv6 local connections:\n\
-host    all         all         ::1/128               md5\n"
+"# TYPE  DATABASE    USER        CIDR-ADDRESS          METHOD\n" \
+"\n" \
+"# local is for Unix domain socket connections only\n" \
+"# trust allows connection from the current PC without a password:\n" \
+"local   all         all                               trust\n" \
+"local   all         all                               ident sameuser\n" \
+"local   all         all                               md5\n" \
+"\n" \
+"# TCP connections from the same computer, with a password:\n" \
+"host    all         all         127.0.0.1    255.255.255.255    md5\n" \
+"# IPv6 local connections:\n" \
+"host    all         all         ::1/128               md5\n"
 
 #define DEFAULT_CONFIG_PG_HBA_LOCAL_8p4 \
-"# TYPE  DATABASE    USER        CIDR-ADDRESS          METHOD\n\
-\n\
-# local is for Unix domain socket connections only\n\
-# trust allows connection from the current PC without a password:\n\
-local   all         all                               trust\n\
-local   all         all                               ident\n\
-local   all         all                               md5\n\
-\n\
-# TCP connections from the same computer, with a password:\n\
-host    all         all         127.0.0.1    255.255.255.255    md5\n\
-# IPv6 local connections:\n\
-host    all         all         ::1/128               md5\n"
+"# TYPE  DATABASE    USER        CIDR-ADDRESS          METHOD\n" \
+"\n" \
+"# local is for Unix domain socket connections only\n" \
+"# trust allows connection from the current PC without a password:\n" \
+"local   all         all                               trust\n" \
+"local   all         all                               ident\n" \
+"local   all         all                               md5\n" \
+"\n" \
+"# TCP connections from the same computer, with a password:\n" \
+"host    all         all         127.0.0.1    255.255.255.255    md5\n" \
+"# IPv6 local connections:\n" \
+"host    all         all         ::1/128               md5\n"
 
 #define DEFAULT_CONFIG_PG_HBA_REMOTE_EXTRA \
-"\n\
-# IPv4 local connections:\n\
-host    all         all         0.0.0.0/0          md5\n\
-# IPv6 local connections:\n\
-host    all         all         ::1/128               md5\n"
+"\n" \
+"# IPv4 local connections:\n" \
+"host    all         all         0.0.0.0/0          md5\n" \
+"# IPv6 local connections:\n" \
+"host    all         all         ::1/128               md5\n"
 
 #define PORT_POSTGRESQL_SELF_HOSTED_START 5433
 #define PORT_POSTGRESQL_SELF_HOSTED_END 5500
@@ -475,8 +476,8 @@ bool PostgresSelfHosted::startup(const SlotProgress& slot_progress, bool network
     return false;
   }
 
-  const Glib::ustring port_as_text = Utils::string_from_decimal(available_port);
-
+  //TODO: Performance:
+  const std::string port_as_text = Glib::Ascii::dtostr(available_port);
 
   // -D specifies the data directory.
   // -c config_file= specifies the configuration file
@@ -746,6 +747,9 @@ int PostgresSelfHosted::discover_first_free_port(int start_port, int end_port)
 
 bool PostgresSelfHosted::create_text_file(const std::string& file_uri, const std::string& contents)
 {
+  if(file_uri.empty())
+    return false;
+
   Glib::RefPtr<Gio::File> file = Gio::File::create_for_uri(file_uri);
   Glib::RefPtr<Gio::FileOutputStream> stream;
 
@@ -820,7 +824,10 @@ bool PostgresSelfHosted::create_text_file(const std::string& file_uri, const std
 
 bool PostgresSelfHosted::directory_exists_uri(const std::string& uri)
 {
-  Glib::RefPtr<Gio::File> file = Gio::File::create_for_uri(uri);
+  if(uri.empty())
+    return false;
+
+  const Glib::RefPtr<Gio::File> file = Gio::File::create_for_uri(uri);
   return file && file->query_exists();
 }
 
