@@ -37,6 +37,9 @@ class Dialog_ButtonScript
 
 {
 public:
+  static const char* glade_id;
+  static const bool glade_developer;
+  
   Dialog_ButtonScript(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder);
   virtual ~Dialog_ButtonScript();
 
