@@ -18,10 +18,11 @@
  * Boston, MA 02111-1307, USA.
  */
 
+#include "config.h"
 #include <glom/utility_widgets/filechooserdialog_saveextras.h>
-#include <glom/libglom/utils.h>
+#include <glom/utils_ui.h>
 #include <gtkmm/alignment.h>
-#include <bakery/App/App_Gtk.h> //For util_bold_message().
+#include <libglom/utils.h> //For bold_message()).
 #include <glibmm/i18n.h>
 
 namespace Glom
@@ -39,13 +40,13 @@ FileChooserDialog_SaveExtras::FileChooserDialog_SaveExtras(Gtk::Window& parent,
   create_child_widgets();
 }
 
-FileChooserDialog_SaveExtras::FileChooserDialog_SaveExtras (const Glib::ustring& title, Gtk::FileChooserAction action)
+FileChooserDialog_SaveExtras::FileChooserDialog_SaveExtras(const Glib::ustring& title, Gtk::FileChooserAction action)
 : Gtk::FileChooserDialog(title, action)
 {
   create_child_widgets();
 }
 
-FileChooserDialog_SaveExtras::FileChooserDialog_SaveExtras (Gtk::Window& parent, const Glib::ustring& title, Gtk::FileChooserAction action)
+FileChooserDialog_SaveExtras::FileChooserDialog_SaveExtras(Gtk::Window& parent, const Glib::ustring& title, Gtk::FileChooserAction action)
 : Gtk::FileChooserDialog(parent, title, action)
 {
   create_child_widgets();
@@ -63,13 +64,15 @@ void FileChooserDialog_SaveExtras::set_extra_message(const Glib::ustring& messag
 
 void FileChooserDialog_SaveExtras::create_child_widgets()
 {
+  set_icon_name("glom");
+
   //m_extra_widget.pack_start(m_label_extra_message);
   m_label_extra_message.set_alignment(0.0f, 0.5f);
   m_label_extra_message.show();
 
   Gtk::Frame* frame = Gtk::manage(new Gtk::Frame());
   Gtk::Label* frame_label = Gtk::manage(new Gtk::Label());
-  frame_label->set_markup(Bakery::App_Gtk::util_bold_message(_("New Database")));
+  frame_label->set_markup(Utils::bold_message(_("New Database")));
   frame_label->show();
   frame->set_label_widget(*frame_label);
   frame->set_shadow_type(Gtk::SHADOW_NONE);
@@ -91,31 +94,68 @@ void FileChooserDialog_SaveExtras::create_child_widgets()
   label_newdb->show();
 
   Gtk::HBox* box_label = Gtk::manage(new Gtk::HBox(false, Utils::DEFAULT_SPACING_SMALL));
-  Gtk::Label* label_title = Gtk::manage(new Gtk::Label(_("Title")));
+  Gtk::Label* label_title = Gtk::manage(new Gtk::Label(_("_Title:"), true));
   box_label->pack_start(*label_title, Gtk::PACK_SHRINK);
   label_title->show();
   box_label->pack_start(m_entry_title);
+  m_entry_title.get_accessible()->set_name(_("Title"));
   m_entry_title.show();
   box_label->show();
   vbox->pack_start(*box_label);
 
+
 #ifndef GLOM_ENABLE_CLIENT_ONLY
-  m_radiobutton_server_postgres_selfhosted.set_label(_("Create postgresql database in its own folder, to be hosted by this computer."));
+
+#ifdef GLOM_ENABLE_SQLITE
+
+#ifdef GLOM_ENABLE_POSTGRESQL
+  //Use titles that show the distinction between PostgreSQL and SQLite:
+  m_radiobutton_server_postgres_selfhosted.set_label(_("Create PostgreSQL database in its own folder, to be hosted by this computer."));
   vbox->pack_start(m_radiobutton_server_postgres_selfhosted);
   m_radiobutton_server_postgres_selfhosted.show();
 
-  m_radiobutton_server_postgres_central.set_label(_("Create database on an external postgresql database server, to be specified in the next step."));
+  m_radiobutton_server_postgres_central.set_label(_("Create database on an external PostgreSQL database server, to be specified in the next step."));
   Gtk::RadioButton::Group group = m_radiobutton_server_postgres_selfhosted.get_group();
   m_radiobutton_server_postgres_central.set_group(group);
   vbox->pack_start(m_radiobutton_server_postgres_central);
   m_radiobutton_server_postgres_central.show();
 
   m_radiobutton_server_sqlite.set_label(_("Create SQLite database in its own folder, to be hosted by this computer."));
-  m_radiobutton_server_sqlite.set_tooltip_text(_("SQLite is more light-weight than postgresql, but it does not support authentication or remote access."));
+  m_radiobutton_server_sqlite.set_tooltip_text(_("SQLite does not support authentication or remote access but is suitable for embedded devices."));
   m_radiobutton_server_sqlite.set_group(group);
   vbox->pack_start(m_radiobutton_server_sqlite);
   m_radiobutton_server_sqlite.show();
+
   m_radiobutton_server_postgres_selfhosted.set_active(true); // Default
+#else
+  //Only SQLite:
+  std::cerr << "WARNING: Glom was built with developer mode (not client-only) but with only support for SQLite. This is very unusual. Postgres is the default backend so it should not be hidden from developers." << std::endl; 
+  //TODO: Hide this because it's the only radio button, so it's not a choice:
+  m_radiobutton_server_sqlite.set_label(_("Create database in its own folder, to be hosted by this computer, using SQLite"));
+  //m_radiobutton_server_sqlite.set_group(group);
+  vbox->pack_start(m_radiobutton_server_sqlite);
+  m_radiobutton_server_sqlite.show();
+#endif // GLOM_ENABLE_POSTGRESQL
+
+#else //GLOM_ENABLE_SQLITE
+  //Only PostgreSQL:
+  //Use titles that don't mention the boring name of the backend:
+  m_radiobutton_server_postgres_selfhosted.set_label(_("Create database in its own folder, to be hosted by this computer."));
+  vbox->pack_start(m_radiobutton_server_postgres_selfhosted);
+  m_radiobutton_server_postgres_selfhosted.show();
+
+  m_radiobutton_server_postgres_central.set_label(_("Create database on an external database server, to be specified in the next step."));
+  Gtk::RadioButton::Group group = m_radiobutton_server_postgres_selfhosted.get_group();
+  m_radiobutton_server_postgres_central.set_group(group);
+  vbox->pack_start(m_radiobutton_server_postgres_central);
+  m_radiobutton_server_postgres_central.show();
+
+  m_radiobutton_server_postgres_selfhosted.set_active(true); // Default
+
+#endif //GLOM_ENABLE_SQLITE
+
+
+
 #endif // !GLOM_ENABLE_CLIENT_ONLY
 
 
@@ -130,19 +170,24 @@ void FileChooserDialog_SaveExtras::set_extra_newdb_title(const Glib::ustring& ti
   m_entry_title.set_text(title);
 }
 
-void FileChooserDialog_SaveExtras::set_extra_newdb_hosting_mode(Document_Glom::HostingMode mode)
+void FileChooserDialog_SaveExtras::set_extra_newdb_hosting_mode(Document::HostingMode mode)
 {
   switch(mode)
   {
-  case Document_Glom::POSTGRES_CENTRAL_HOSTED:
+#ifdef GLOM_ENABLE_POSTGRESQL
+  case Document::HOSTING_MODE_POSTGRES_CENTRAL:
     m_radiobutton_server_postgres_central.set_active();
     break;
-  case Document_Glom::POSTGRES_SELF_HOSTED:
+  case Document::HOSTING_MODE_POSTGRES_SELF:
     m_radiobutton_server_postgres_selfhosted.set_active();
     break;
-  case Document_Glom::SQLITE_HOSTED:
+#endif //GLOM_ENABLE_POSTGRESQL
+
+#ifdef GLOM_ENABLE_SQLITE
+  case Document::HOSTING_MODE_SQLITE:
     m_radiobutton_server_sqlite.set_active();
     break;
+#endif //GLOM_ENABLE_SQLITE
   default:
     g_assert_not_reached();
     break;
@@ -154,14 +199,27 @@ Glib::ustring FileChooserDialog_SaveExtras::get_extra_newdb_title() const
   return m_entry_title.get_text();
 }
 
-Document_Glom::HostingMode FileChooserDialog_SaveExtras::get_extra_newdb_hosting_mode() const
+Document::HostingMode FileChooserDialog_SaveExtras::get_extra_newdb_hosting_mode() const
 {
+#ifdef GLOM_ENABLE_POSTGRESQL
   if(m_radiobutton_server_postgres_central.get_active())
-    return Document_Glom::POSTGRES_CENTRAL_HOSTED;
+    return Document::HOSTING_MODE_POSTGRES_CENTRAL;
   else if(m_radiobutton_server_postgres_selfhosted.get_active())
-    return Document_Glom::POSTGRES_SELF_HOSTED;
-  else
-    return Document_Glom::SQLITE_HOSTED;
+    return Document::HOSTING_MODE_POSTGRES_SELF;
+#endif //GLOM_ENABLE_POSTGRESQL
+
+#ifdef GLOM_ENABLE_SQLITE
+  if(m_radiobutton_server_sqlite.get_active())
+    return Document::HOSTING_MODE_SQLITE;
+#endif //GLOM_ENABLE_SQLITE
+
+  g_assert_not_reached();
+
+#ifdef GLOM_ENABLE_SQLITE
+  return Document::HOSTING_MODE_SQLITE; //Arbitrary
+#else
+  return Document::HOSTING_MODE_POSTGRES_SELF; //Arbitrary.
+#endif //GLOM_ENABLE_SQLITE
 }
 
 } //namespace Glom
