@@ -174,6 +174,7 @@ void Utils::show_ok_dialog(const Glib::ustring& title, const Glib::ustring& mess
 #else
   Gtk::MessageDialog dialog("<b>" + title + "</b>", true /* markup */, message_type, Gtk::BUTTONS_OK);
   dialog.set_secondary_text(message);
+  dialog.set_icon_name("glom");
   if(parent)
     dialog.set_transient_for(*parent);
 #endif
@@ -282,11 +283,6 @@ Glib::RefPtr<Gdk::Pixbuf> Utils::get_pixbuf_for_gda_value(const Gnome::Gda::Valu
 #ifdef GLIBMM_EXCEPTIONS_ENABLED
         try
         {
-
-          //g_warning("ImageGlom::set_value(): debug: from db: ");
-          //for(int i = 0; i < 10; ++i)
-          //  g_warning("%02X (%c), ", (guint8)puiData[i], (char)puiData[i]);
-
           refPixbufLoader->write(puiData, (glong)buffer_binary_length);
           result = refPixbufLoader->get_pixbuf();
 
@@ -437,4 +433,69 @@ std::string Utils::get_filepath_with_extension(const std::string& filepath, cons
 }
 
 
+//static:
+Glib::RefPtr<Gdk::Pixbuf> Utils::image_scale_keeping_ratio(const Glib::RefPtr<Gdk::Pixbuf>& pixbuf, int target_height, int target_width)
+{
+  if( (target_height == 0) || (target_width == 0) )
+    return Glib::RefPtr<Gdk::Pixbuf>(); //This shouldn't happen anyway.
+
+  if(!pixbuf)
+    return pixbuf;
+
+  enum enum_scale_mode
+  {
+    SCALE_WIDTH,
+    SCALE_HEIGHT,
+    SCALE_NONE
+  };
+
+  enum_scale_mode scale_mode = SCALE_NONE; //Start with either the width or height, and scale the other according to the ratio.
+
+  const int pixbuf_height = pixbuf->get_height();
+  const int pixbuf_width = pixbuf->get_width();
+
+  if(pixbuf_height > target_height)
+  {
+    if(pixbuf_width > target_width)
+    {
+      //Both are bigger than the target, so find the biggest one:
+      if(pixbuf_width > pixbuf_height)
+        scale_mode = SCALE_WIDTH;
+      else
+        scale_mode = SCALE_HEIGHT;
+    }
+    else
+    {
+      //Only the height is bigger:
+      scale_mode = SCALE_HEIGHT;
+    }
+  }
+  else if(pixbuf_width > target_width)
+  {
+    //Only the height is bigger:
+    scale_mode = SCALE_WIDTH;
+  }
+
+  if(scale_mode == SCALE_NONE)
+    return pixbuf;
+  else if(scale_mode == SCALE_HEIGHT)
+  {
+    const float ratio = (float)target_height / (float)pixbuf_height; 
+    target_width = (int)((float)pixbuf_width * ratio);
+  }
+  else if(scale_mode == SCALE_WIDTH)
+  {
+    const float ratio = (float)target_width / (float) pixbuf_width;
+    target_height = (int)((float)pixbuf_height * ratio);
+  }
+
+ if( (target_height == 0) || (target_width == 0) )
+ {
+   return Glib::RefPtr<Gdk::Pixbuf>(); //This shouldn't happen anyway. It seems to happen sometimes though, when ratio is very small.
+ }
+
+  return pixbuf->scale_simple(target_width, target_height, Gdk::INTERP_NEAREST);
+}
+
+
 } //namespace Glom
